class InvalidSlotSize(Exception):
    """Raised when slot size is invalid.
    """

    pass


class MultipleGames(Exception):
    """Raised when you attempt to create one server
       with multiple games.
    """

    pass


class InvalidTickrate(Exception):
    """Raised when tickrate is invalid.
    """

    pass


class InvalidConsoleLine(Exception):
    """Raised when console line is above 1 or above 100000.
    """

    pass


class AwaitingOnly(Exception):
    """Raised when a coroutine called is awaiting supported only.
    """

    pass


class InvalidSteamID(Exception):
    """Raised when give ID isn't understood.
    """

    pass


class NotFound(Exception):
    """Resource not found.
    """

    pass


class BadRequest(Exception):
    """Path is a directory or Cannot move file into itself.
    """

    pass


class ExceededStorage(Exception):
    """Your disk quota of 30GB per server (excluding base installation)
    has been exceeded
    """

    pass


class ServerStart(Exception):
    """Failed to start server.
    """

    pass



import typing

from httpx import Response

from ..exceptions import (
    NotFound,
    BadRequest,
    ExceededStorage,
    ServerStart
)


class BaseHttp:
    def handle_resp(self, resp: Response, json: bool = True,
                    read: bool = True) -> typing.Any:
        """Handles resp response.

        Parameters
        ----------
        resp : Response
        json : bool, optional
            by default True
        read : bool, optional
            by default True
        """

        if resp.status_code == 404:
            raise NotFound()
        elif resp.status_code == 400:
            raise BadRequest()
        elif resp.status_code == 507:
            raise ExceededStorage()
        elif resp.status_code == 500:
            raise ServerStart()
        elif resp.status_code != 200:
            resp.raise_for_status()

        if json:
            return resp.json()
        elif read:
            return resp.read()
        else:
            return True
